@@ -5,7 +5,7 @@ class Base(object):
     date_format = '%Y-%m-%d'
     time_format = '%H:%M:%S'
     datetime_format = date_format + 'T%s' % time_format
-    full_datetime_format = date_format + 'T' + time_format + '%f'
+    full_datetime_format = date_format + 'T' + time_format + '.%f'
     iso_format = date_format + 'T%sZ' % time_format
     standard_datetime_format = date_format + ' ' + time_format
     extended_datetime_format = date_format + 'T' + time_format +'.%fZ'
